"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _create = _interopRequireDefault(require("babel-plugin-espower/create"));

var _checkStatically = _interopRequireDefault(require("./check-statically"));

var _generateAssertIdentifier = _interopRequireDefault(require("./generate-assert-identifier"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = (babel, state, config) => statementPath => {
  const t = babel.types;
  const scope = statementPath.scope,
        statement = statementPath.node;

  if (t.isExpressionStatement(statement)) {
    const expressionPath = statementPath.get('expression');
    (0, _checkStatically.default)(expressionPath, config);
    const origExpr = statement.expression;
    const assertIdentifier = (0, _generateAssertIdentifier.default)(t, config)(scope);
    assertIdentifier.loc = {
      start: origExpr.loc.start,
      end: origExpr.loc.start
    };
    const newExpr = t.callExpression(assertIdentifier, [origExpr]);
    newExpr.loc = origExpr.loc;
    statement.expression = newExpr; // register added import with scope so it is found for the next assertion
    // for some reason, this needs to happen after we have referenced the import
    // with our call expression, otherwise the import will be removed

    scope.getProgramParent().crawl();

    if (config.powerAssert) {
      // Now let espower generate nice power assertions for this assertion
      (0, _create.default)(babel, {
        embedAst: true,
        patterns: [`${assertIdentifier.name}(value)`]
      }).visitor.Program(statementPath, state);
    }
  } else {
    throw statementPath.buildCodeFrameError(`Expected an expression statement, but got a statement of type ${statementPath.type}`);
  }
};

exports.default = _default;