/**
 * Config after sanitizing in extractConfigFromState.
 */
export interface InternalConfig {
    powerAssert: boolean;
    autoImport: string;
    staticTruthCheck: boolean;
    assertFunctionName: string;
}
/**
 * Config as it can be provided by the user.
 * Comments indicate transformations made to conform to InternalConfig format.
 */
export interface Config {
    powerAssert?: boolean;
    autoImport?: boolean | string;
    staticTruthCheck?: boolean;
    assertFunctionName?: string;
}
/**
 * Config containing the settings used if they are missing in the user-specified config.
 */
export declare const defaultConfig: {
    powerAssert: boolean;
    autoImport: boolean;
    staticTruthCheck: boolean;
    assertFunctionName: string;
};
/**
 * Config that disables all but the core set of features.
 */
export declare const minimalConfig: {
    powerAssert: boolean;
    autoImport: boolean;
};
export declare const extractConfigFromState: ({ opts: { powerAssert, autoImport, staticTruthCheck, assertFunctionName }, }: {
    opts: Config;
}) => InternalConfig;
