"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
const DEFAULT_ASSERTION_FUNCTION_NAME_HINT = 'assert';

const findExistingImportFromSource = (scope, t, source) => {
  const program = scope.getProgramParent().path.node; // try to find existing default import from source

  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = program.body[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      const stmt = _step.value;

      if (t.isImportDeclaration(stmt) && stmt.source.value === source) {
        const defaultSpecifier = stmt.specifiers.find(specifier => t.isImportDefaultSpecifier(specifier));

        if (defaultSpecifier) {
          const local = defaultSpecifier.local;
          const name = local.name; // make sure the import is not shadowed in the scope

          if (scope.bindingIdentifierEquals(name, local)) {
            return name;
          }
        }
      }
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return != null) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  return;
};

const addImport = (scope, t, source, name) => {
  if (name) {
    // clear possible binding conflicts
    scope.rename(name);
  }

  const program = scope.getProgramParent().path; // Generate default import from exact name or default name hint.
  // Using @babel/helper-module-imports would give us commonjs support
  // for free without requiring @babel/preset-env, however
  // 1. it does not support exact names, so we would still need to
  //    use our manual import generation if assertFunctionName is set and
  // 2. it might generate SequenceExpressions instead of Identifiers,
  //    which are annoying to deal with because of powerAssert patterns.

  const id = name ? t.identifier(name) : scope.generateUidIdentifier(DEFAULT_ASSERTION_FUNCTION_NAME_HINT);
  program.unshiftContainer('body', t.importDeclaration([t.importDefaultSpecifier(id)], t.stringLiteral(source)));
  return id;
};

var _default = (t, {
  autoImport: importSource,
  assertFunctionName
}) => scope => {
  if (importSource) {
    const name = findExistingImportFromSource(scope, t, importSource);

    if (name) {
      return t.identifier(name);
    }

    return addImport(scope, t, importSource, assertFunctionName);
  }

  return t.identifier(assertFunctionName || DEFAULT_ASSERTION_FUNCTION_NAME_HINT);
};

exports.default = _default;